// iod_mgmt.h file: iod management
// defines the structures used to set up the raidset on viod
//
//
// Author: Adrien Lebre <adrien.lebre@imag.fr>
// Coauthor: Pierre Lombard <pierre.lombard@imag.fr>
// Coauthor: Olivier Valentin <olivier.valentin@imag.fr>
// Date: 2002xxxx
// Licence: GPL

#ifndef __IOD_MGMT_H__
#define __IOD_MGMT_H__ 1

// #include "default.h"

// Used to enable (1) / disable (0) NFSp support (TEST mode)
#define IOD_MGMT_WITH_NFSP 1

// Defines double-linked list
#include "list.h"

// Interaction with nfsp demon
// Used to add iods and bind iod to viod.
//#include "ioctl.h"

//#include <rpc/rpc_msg.h>
//#include "nfs_prot.h"

#include <netinet/in.h>		// used for sockaddr_in structure and inet_ntoa function

// This #define's try to make this app compile smoothly on most Linux
// installations... Check /usr/include/netinet/in.h in doubt.
#define in_addr_t uint32_t
#define in_port_t uint16_t

typedef enum {
	IOD_DOWN = 0,		// Used for iod status
	IOD_UP = 1,		// Used for iod status
	IOD_NOTLINKED = -1,	// Used when an iod is not linked to any viod
} iod_state_set_t;

// This structure contains required informations to manage iods and viods.
typedef struct {
	struct list_head FromAndToList;	// Contains 2 Ptr (prev and next) from an to the last and the next iod in the
	// same list (Free or Used).
	struct sockaddr_in iod;		// IP + iod port
	int check_ok;			// Status: up=1 or down=0 (the iod replies to the ping or not)
	struct timeval check_time;	// Date of the last check
	int iRelated_viod;		// The viod where the iod has been assigned.
	int iKernelHandle;		// The handle assign by nfsp kernel when you add a new iod.

} iod_info_t;

// The max length for an iod description
#define MAXLINELEN 	512

// This structure contains informations sent by an instance of iod_mgmt to the first (Interact Thread)
typedef struct {
	int iType;
	char cTabParam[MAXLINELEN + 1];	// e.g.: "icluster1:20000 1" 
} interact_request_t;

#define IOD_MGMT_CMD_ADD_IOD 			0	// Type of interact_request
#define IOD_MGMT_CMD_FREE_IOD 			1
#define IOD_MGMT_CMD_LIST_IOD 			2
#define IOD_MGMT_CMD_FLUSH_IOD			3
#define IOD_MGMT_CMD_STOP_IOD			4
#define IOD_MGMT_CMD_SET_PING_PARAMETERS	5
#define IOD_MGMT_CMD_GET_PING_PARAMETERS 	6
#define IOD_MGMT_CMD_SET_VIODS_NB 		7
//#define IOD_MGMT_CMD_GET_VIODS_NB             8
#define IOD_MGMT_CMD_SET_NFSP_MODE		9
#define IOD_MGMT_CMD_GET_NFSP_MODE		10

// enables to know the nfsp mode
typedef enum {
	IOD_MGMT_MODE_DROP,
	IOD_MGMT_MODE_FORWARD,
} NFSpMode_t;

#if IOD_MGMT_WITH_NFSP == 0
#warning "****************************************************"
#warning "*** TEST MODE : NFSP SUPPORT IS ### DISABLED ### ***"
#warning "****************************************************"
#endif

// The other functions are defined in "static" way. see iod_mgmt.c

#endif
