/*
 * logging.h	Definitions for the logging functions.
 *
 * Authors:	Donald J. Becker, <becker@super.org>
 *		Rick Sladkey, <jrs@world.std.com>
 *		Fred N. van Kempen, <waltje@uWalt.NL.Mugnet.ORG>
 *
 *		This software maybe be used for any purpose provided
 *		the above copyright notice is retained.  It is supplied
 *		as is, with no warranty expressed or implied.
 */

#ifndef LOGGING_H
#define LOGGING_H 1

#include <rpc/rpc.h>

/* Logging/Debug levels */
#define L_ERROR		(1<<0)
#define L_WARNING	(1<<1)
#define L_NOTICE	(1<<2)
#define L_FATAL		(1<<3)
#define L_MASK		0x0000000F

#define D_GENERAL	(1<<8)
#define D_CALL		(1<<9)
#define D_FHCACHE	(1<<10)
#define D_AUTH		(1<<11)
#define D_UGID		(1<<12)
#define D_RMTAB		(1<<13)
#define D_FHTRACE	(1<<14)
#define D_DEVTAB	(1<<15)

#define D_NFSP		(1<<16)
#define D_NFSP_DISPATCH	(1<<17)
#define D_NFSP_NFSD	(1<<18)
#define D_UNLINKD	(1<<19)
#define D_NFSP_UDPSPOOF	(1<<20)
#define D_NFSP_IODS	(1<<21)
#define D_NFSP_VIODS	(1<<22)
#define D_NFSP_GETATTR	(1<<23)

#define D_IOD		(1<<28)
#define D_IODMGR	(1<<29)
#define D_LIBSTRIPING	(1<<30)

#define D_MASK		0x70FFFF00

#define D_NFSPD		(D_NFSP_DISPATCH | D_NFSP_NFSD | D_UNLINKD | D_NFSP_UDPSPOOF | \
			D_NFSP_IODS | D_NFSP_VIODS | D_NFSP_GETATTR)
#define D_STALE		(D_AUTH | D_CALL | D_FHCACHE | D_FHTRACE)

#define D_ALL		(L_MASK | D_MASK)

/* Global Function prototypes. */
extern void log_open(char *progname, int foreground);
extern void log_close(void);
extern void enable_logging(char *kind);
extern int  logging_enabled(int level);
extern void toggle_logging(int sig);
extern void background_logging(void);
extern void Dprintf(unsigned int level, const char *fmt, ...);
extern void log_call(struct svc_req *rqstp, char *name,	char *arg);

#endif /* LOGGING_H */

/* End of logging.h. */
