// "atomic" I/O on sockets
//
// Author: Pierre Lombard <pierre.lombard@imag.fr> 2002/07 GPLv2

#include <sys/types.h>
#include <sys/socket.h>
#include <unistd.h>


#include "sure_sock.h"

typedef int (*xxxx_t)(int, void*, size_t, int);

static inline int sure_xxxx(xxxx_t xxxx,
			  const int s, void *buffer, const size_t len, const int flags) {
        int bytesread;
        int offset = 0;
        int toread = len;

        while (toread > 0) {
                bytesread = xxxx(s, (char*)buffer + offset, toread, flags);
                if (-1 == bytesread) {
                        // errno is set by xxxx
                        return -1;
                } else if (0 == bytesread) {
                        return 0;
                } else {
                        // we read/wrote some bytes (possibly not all)
                        offset += bytesread;
                        toread -= bytesread;
                }
        }
        return offset;
}

int sure_recv(int s, void *msg, size_t len, int flags) {
	return sure_xxxx(recv, s, msg, len, flags);
}

int sure_send(int s, const void *msg, size_t len, int flags) {
	return sure_xxxx((xxxx_t) send, s, (void *)msg, len, flags);
}

ssize_t sure_read(int fd, void *buf, size_t count) {
	return sure_xxxx(recv, fd, buf, count, 0);
}

ssize_t sure_write(int fd, const void *buf, size_t count) {
	return sure_xxxx((xxxx_t) send, fd, (void *) buf, count, 0);
}

